pub struct SessionKeyDisplay<'a> { /* private fields */ }Expand description
Helper struct for intentionally printing session keys with format! and {}.
This struct implements the Display trait to print the session key. This
construct requires the user to explicitly call
SessionKey::display_sensitive. By requiring the user to opt-in, this
will hopefully reduce that the chance that the session key is inadvertently
leaked, e.g., in a log that may be publicly posted.